@@ -1,3 +1,23 @@
+/*
+ * evopedia: An offline Wikipedia reader.
+ *
+ * Copyright (C) 2010-2011 evopedia developers
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
+
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
@@ -38,7 +58,7 @@ private slots:
     void on_listView_activated(QModelIndex index);
     void on_searchField_textChanged(const QString &text);
     void mapViewRequested(qreal lat, qreal lon, uint zoom);
-    void backendsChanged(const QList<LocalArchive *>backends);
+    void backendsChanged(QList<LocalArchive *>backends);
 
     void refreshSearchResults();
 
